# Concordia- WIP

[![Build Status](https://travis-ci.org/ClimbsRocks/Concordia.svg?branch=master)](https://travis-ci.org/ClimbsRocks/Concordia)
[![License](https://img.shields.io/github/license/mashape/apistatus.svg)]((https://img.shields.io/github/license/mashape/apistatus.svg))

Concordia is under active development right now, and aims to be a part of a suite of open-source machine learning packages that allow organizations to more rapidly develop and deploy machine learning models.

Using Concordia, you should be able to rapidly have confidence in your shipped ML models.

If everything's working as expected, you should be able to see that, and heave a sigh of relief.

If things are not going according to plan, again, you should be able to see that rapidly, and nearly as quickly see the root cause of those discrepancies.

It's designed to work across environments, with many critical parameters configurable (such as database settings).

